'use client';
import { createAsyncThunk, createSlice } from '@reduxjs/toolkit';
import { useAuth } from '../contexts/AuthContext';
import axios, { axiosPrivate } from '../api/axios';

interface FuturesPrice {
    symbol: string;
    bidPrice: string;
    bidQty: string;
    askPrice: string;
    askQty: string;
    time: number;
    lastUpdateId: number;
}

interface FuturesPriceState {
    data: FuturesPrice[];
    isLoading: boolean;
    errorMessage: string;
}

const initialState: FuturesPriceState = {
    data: [],
    isLoading: false,
    errorMessage: '',
};

export const fetchFuturesPrices = createAsyncThunk('futuresPrice/fetchFuturesPrices', async () => {
    try {
        const response = await axios.get<FuturesPrice[]>('/futures/prices');
        return response.data;
    } catch (error) {
        throw new Error('Failed to fetch futures prices');
    }
});

const futuresPriceSlice = createSlice({
    name: 'futuresPrice',
    initialState,
    reducers: {},
    extraReducers: (builder) => {
        builder
            .addCase(fetchFuturesPrices.pending, (state) => {
                state.isLoading = true;
                state.errorMessage = '';
            })
            .addCase(fetchFuturesPrices.fulfilled, (state, action) => {
                state.isLoading = false;
                state.data = action.payload;
            })
            .addCase(fetchFuturesPrices.rejected, (state, action) => {
                state.isLoading = false;
                state.errorMessage = action.error.message ?? 'Failed to fetch futures prices';
            });
    },
});

export default futuresPriceSlice.reducer;
